module.exports={A:{A:{"2":"J D E F 5C","8":"A B"},B:{"1":"P","2":"0 1 2 3 4 5 6 7 8 9 H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB","8":"C K L G M N O"},C:{"2":"0 1 2 3 4 5 6 7 8 9 6C YC I eB J D E F A B C K L G M N O fB AB BB CB ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC 7C 8C 9C AD","66":"DB EB FB GB HB IB JB","72":"gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B"},D:{"1":"jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B ZC 9B aC AC BC CC DC EC FC GC HC IC JC KC LC MC NC OC PC QC P","2":"0 1 2 3 4 5 6 7 8 9 I eB J D E F A B C K L G M N O fB AB BB CB DB EB FB GB H Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB bB cB dB KB cC RC dC","66":"HB IB JB gB hB iB"},E:{"2":"I eB BD eC CD","8":"J D E F A B C K L G DD ED FD fC SC TC GD HD ID gC hC UC JD VC iC jC kC lC mC KD WC nC oC pC qC rC LD XC sC tC uC vC wC xC yC zC 0C 1C 2C MD"},F:{"1":"AB BB CB DB EB FB GB HB IB JB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC","2":"0 1 2 3 4 5 6 7 8 9 F B C FC GC HC IC JC KC LC MC NC OC PC QC P H Q bC R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z ND OD PD QD SC 3C RD TC","66":"G M N O fB"},G:{"2":"eC SD 4C TD UD","8":"E VD WD XD YD ZD aD bD cD dD eD fD gD hD iD jD kD lD gC hC UC mD VC iC jC kC lC mC nD WC nC oC pC qC rC oD XC sC tC uC vC wC xC yC zC 0C 1C 2C"},H:{"2":"pD"},I:{"1":"vD","2":"YC I KB qD rD sD tD 4C uD"},J:{"2":"D A"},K:{"2":"A B C H SC 3C TC"},L:{"2":"KB"},M:{"2":"RC"},N:{"2":"A B"},O:{"1":"UC"},P:{"1":"I wD xD yD zD 0D fC 1D 2D","2":"AB BB CB DB EB FB GB HB IB JB 3D 4D 5D VC WC XC 6D"},Q:{"1":"7D"},R:{"2":"8D"},S:{"2":"AE","72":"9D"}},B:7,C:"Custom Elements (deprecated V0 spec)",D:true};
